| /llvm-project-15.0.7/clang/test/SemaCXX/ |
| H A D | warn-tautological-compare.cpp | 66 int fun2(); 76 (void)CallFunction(fun2); in ignore() 82 if (fun2 == 0) {} in test() 96 if (nullptr != fun2) {} in test()
|
| H A D | member-expr.cpp | 136 S fun2(); // expected-note{{possible target for call}} 137 S fun2(int i); // expected-note{{possible target for call}} 139 …return fun2.x; // expected-error{{reference to overloaded function could not be resolved; did you … in g2() 164 Vec *fun2(); 165 …int test2() { return fun2->size(); } // expected-error {{base of member reference is a function; p… in test2()
|
| /llvm-project-15.0.7/llvm/test/tools/llvm-split/ |
| H A D | scc-comdat.ll | 9 ; CHECK0: declare dso_local i32 @fun2 13 ; CHECK1: define internal i32 @fun2 23 define internal i32 @fun2() section ".text.funs" comdat($fun) {
|
| /llvm-project-15.0.7/llvm/test/CodeGen/SystemZ/ |
| H A D | vec-perm-14.ll | 66 define <4 x i8> @fun2(<2 x i8> %arg) { 85 ; CHECK-NEXT: .globl fun2 87 ; CHECK-NEXT: .type fun2,@function 88 ; CHECK-NEXT:fun2: # @fun2
|
| H A D | fp-conv-18.ll | 7 ; CHECK-LABEL: fun2: 23 define void @fun2() #0 {
|
| /llvm-project-15.0.7/llvm/test/LTO/Resolution/X86/ |
| H A D | symtab.ll | 20 ; CHECK: D------X @fun2@8 21 ; CHECK-NEXT: comdat any @fun2@8 22 $fun2 = comdat any 23 define x86_fastcallcc i32 @fun2(i32 inreg %a, i32 inreg %b) comdat {
|
| /llvm-project-15.0.7/llvm/test/CodeGen/X86/ |
| H A D | prologue-epilogue-remarks.mir | 7 define void @fun2() noredzone { ret void } 48 name: fun2 54 # CHECK-NEXT: Function: fun2
|
| /llvm-project-15.0.7/clang/test/Sema/ |
| H A D | alias-redefinition.c | 11 void fun2(void) __attribute((alias("f2"))); // expected-note {{previous definition}} 12 void fun2() {} // expected-error {{redefinition of 'fun2'}} in fun2() function
|
| /llvm-project-15.0.7/clang/test/OpenMP/ |
| H A D | vla_iterator_cache_bug.c | 9 extern void fun2(int n, int *a, int *b); 16 fun2(n, a, b); in fun1()
|
| /llvm-project-15.0.7/llvm/test/Transforms/CodeExtractor/ |
| H A D | extract-assume.ll | 10 declare void @fun2(i32) #0 22 call void @fun2(i32 %x)
|
| /llvm-project-15.0.7/llvm/test/CodeGen/AArch64/ |
| H A D | prologue-epilogue-remarks.mir | 41 name: fun2 47 # CHECK: Function: fun2
|
| /llvm-project-15.0.7/llvm/test/Bitcode/ |
| H A D | blockaddress-users.ll | 11 ; @repro, since @fun and @fun2 both refer to @repro via blockaddress 33 define void @fun2() noinline {
|
| H A D | blockaddress-aggregate-users.ll | 11 ; @repro, since @fun and @fun2 both refer to @repro via blockaddress 35 define void @fun2() noinline {
|
| H A D | blockaddress-expr-users.ll | 11 ; @repro, since @fun and @fun2 both refer to @repro via blockaddress 33 define void @fun2() noinline {
|
| H A D | blockaddress-globalvalue-users.ll | 11 ; fn, @repro, by accident, when @fun and @fun2 use a global value, @foo, 33 define void @fun2() noinline {
|
| H A D | blockaddress-nested-users.ll | 11 ; @repro, since @fun and @fun2 both refer to @repro via blockaddress 33 define void @fun2() noinline {
|
| /llvm-project-15.0.7/clang/test/CodeGenCUDA/ |
| H A D | host-used-device-var.cu | 106 __host__ __device__ void fun2() { in fun2() function 115 fun2(); in kern1()
|
| H A D | builtin-mangled-name.cu | 26 __host__ __device__ const char *fun2() { in fun2() function
|
| H A D | noinline.cu | 16 __attribute__((noinline)) __device__ __host__ void fun2() {} in fun2() function
|
| /llvm-project-15.0.7/llvm/test/MC/AsmParser/ |
| H A D | altmacro_string.s | 55 .macro fun2 arg macro 59 fun2 <5,6>
|
| /llvm-project-15.0.7/llvm/test/Analysis/CostModel/SystemZ/ |
| H A D | cmp-tofp.ll | 25 define <2 x double> @fun2(<2 x i64> %val1, <2 x i64> %val2) { 30 ; CHECK: fun2
|
| /llvm-project-15.0.7/clang/test/CodeGenCXX/ |
| H A D | PR20038.cpp | 14 bool fun2() { return (C(), b) && 0; } in fun2() function
|
| /llvm-project-15.0.7/clang/test/PCH/ |
| H A D | struct.c | 23 return fun2->very_fun; in get_very_fun()
|
| H A D | struct.h | 25 struct Fun2 *fun2; variable
|
| /llvm-project-15.0.7/clang/test/SemaCUDA/ |
| H A D | noinline.cu | 9 __attribute__((noinline)) void fun2() { } in fun2() function
|